@@ -117,6 +117,11 @@ class TestTranspile(unittest.TestCase):
             "select x from foo --       x",
             "SELECT x FROM foo /*       x */",
         )
+        self.validate(
+            """select x, --
+            from foo""",
+            "SELECT x FROM foo",
+        )
         self.validate(
             """
 -- comment 1
